//------------------------------------------------------------------------------

// The jquery validation rules, common to all our local authentication pages.
// This assumes that the local HTML file has a validationMessages object.
// The messages in that object are in the HTML file, because that file gets zstring translated.
// Below, we merge the validationData_noMessages and validationMessages objects.

var validationData_noMessages = {

	// If true, error messages will go to the console
	debug: false,

	// Expecting:
	// Email length > 0 and formatted properly
	// Password length > 0
	rules: {
		password: "required",
		email: {
			required: true,
			email: true
		}
	},
	
	// If the form validates, then then the submit action to perform
	submitHandler: function(form) {
		perform_submit_action();
	},
	
	// Set whether to auto focus to an invalid field, base on OS detect in jquery.client.js
	// In desktop versions, allow the first invalid input field to be focused
	// In mobile versions, don't focus, because it will annoyingly bring up the keyboard
	focusInvalid: ( $.client.os == 'Mac' || $.client.os == 'Windows' ),
	
	// Focus only when submitting
	onkeyup: false,
	onclick: false,
	onfocusout: false,
	
	// Where errors gets shown
	errorLabelContainer: "#idErrorBlockDummy",
	
	// Put each error message on its own line in errorLabelContainer
	wrapper: "div",
	
	// Highlight all fields that have an error
	highlight: function( element, errorClass ) {
		$( element ).addClass( "error_field" );
	},
	
	// Unhighlight all fields that DON'T have an error
	unhighlight: function( element, errorClass ) {
		$( element ).removeClass( "error_field" );
	},
	
	// If multiple local form errors, then show a common error message
	// Else, show a field-specific error message
	showErrors: function( errorMap, errorList ) {

		if( this.numberOfInvalids() == 0 ) {
			
			$("#idErrorBlock").hide();
			
		}
		else {
			
			// A single field-specific error message
			var msg = errorList[ 0 ].message;

			// Show the message in our custom element
			$("#idErrorBlock").html( msg ).show();
			
			// Hilight any invalid field
			this.defaultShowErrors();
			
			// Prevent jQuery Validate plugin from showing its own error list
			$("#idErrorBlockDummy").hide();
			
			// Notify the HTML page that local errors are now showing
			if( typeof showingLocalErrorsFunc != 'undefined' && $.isFunction( showingLocalErrorsFunc ) )
				showingLocalErrorsFunc();
			
		}

	}
	
};

//------------------------------------------------------------------------------

// This will be used to programmatically set errors (in response to IMS errors)
var validator;

//------------------------------------------------------------------------------

$(document).ready(function() {

	// Merge validationMessages into validationData_noMessages
	var validation_merged = $.extend( true, validationData_noMessages, validationMessages )

	$("#idErrorBlock, #idErrorBlockDummy").hide();

	validator = $("#idMainForm").validate( validation_merged );

	// This handles both keyup and paste		
	$( '.textInput' ).bind( 'input', function() {
		checkEmptyInput();
	});

});

//------------------------------------------------------------------------------
// Disable/enable the submit button depending on whether any text input field is empty

function checkEmptyInput() {
	
	var empty = false;
	$( '.textInput' ).each( function() {
		if( $( this ).val().length == 0 )
			empty = true;
	});
	
	if( empty ) {
		$( '.submit' ).addClass( 'disabled' );
		$( '.submit' ).prop( 'disabled', true );
	} else {
		$( '.submit' ).removeClass( 'disabled' );
		$( '.submit' ).prop( 'disabled', false );
	}
	
}

//------------------------------------------------------------------------------
// Manually set the userId (passed along from the Reset Password page)

function setUserId( userId ) {
	
	$( "#idSignInAdobeEmail" ).val( userId );
	checkEmptyInput();
	
}

//------------------------------------------------------------------------------


